@@ -5,7 +5,7 @@ use crate::{
     with::{make_with_cast, make_with_ty},
 };
 use proc_macro2::{Span, TokenStream};
-use quote::{quote, quote_spanned};
+use quote::quote;
 use syn::{
     parse_quote, spanned::Spanned, Attribute, Data, DeriveInput, Error, Field, Fields, Ident,
     Index, Meta, NestedMeta, Type,
@@ -145,7 +145,7 @@ fn derive_archive_impl(
                         .iter()
                         .filter(|f| !f.attrs.iter().any(|a| a.path.is_ident("omit_bounds")))
                     {
-                        let ty = with_ty(field);
+                        let ty = with_ty(field)?;
                         archive_where
                             .predicates
                             .push(parse_quote! { #ty: #rkyv_path::Archive });
@@ -153,14 +153,14 @@ fn derive_archive_impl(
 
                     let resolver_fields = fields.named.iter().map(|f| {
                         let name = &f.ident;
-                        let ty = with_ty(f);
-                        quote_spanned! { f.span() => #name: #rkyv_path::Resolver<#ty> }
+                        let ty = with_ty(f).unwrap();
+                        quote! { #name: #rkyv_path::Resolver<#ty> }
                     });
 
                     let archived_def = if attributes.archive_as.is_none() {
                         let archived_fields = fields.named.iter().map(|f| {
                             let field_name = f.ident.as_ref();
-                            let ty = with_ty(f);
+                            let ty = with_ty(f).unwrap();
                             let vis = &f.vis;
                             let field_doc = format!(
                                 "The archived counterpart of [`{}::{}`]",
@@ -168,7 +168,7 @@ fn derive_archive_impl(
                                 field_name.unwrap()
                             );
                             let archive_attrs = field_archive_attrs(f);
-                            quote_spanned! { f.span() =>
+                            quote! {
                                 #[doc = #field_doc]
                                 #(#[#archive_attrs])*
                                 #vis #field_name: #rkyv_path::Archived<#ty>
@@ -190,10 +190,10 @@ fn derive_archive_impl(
 
                     let resolve_fields = fields.named.iter().map(|f| {
                         let name = &f.ident;
-                        let field = with_cast(f, parse_quote! { (&self.#name) });
-                        quote_spanned! { f.span() =>
+                        let field = with_cast(f, parse_quote! { (&self.#name) }).unwrap();
+                        quote! {
                             let (fp, fo) = out_field!(out.#name);
-                            #field.resolve(pos + fp, resolver.#name, fo);
+                            ::rkyv::Archive::resolve(#field, pos + fp, resolver.#name, fo);
                         }
                     });
 
@@ -207,7 +207,7 @@ fn derive_archive_impl(
                                     !f.attrs.iter().any(|a| a.path.is_ident("omit_bounds"))
                                 }) {
                                     let ty = &field.ty;
-                                    let wrapped_ty = with_ty(field);
+                                    let wrapped_ty = with_ty(field).unwrap();
                                     partial_eq_where.predicates.push(
                                         parse_quote! { Archived<#wrapped_ty>: PartialEq<#ty> },
                                     );
@@ -236,7 +236,7 @@ fn derive_archive_impl(
                                     !f.attrs.iter().any(|a| a.path.is_ident("omit_bounds"))
                                 }) {
                                     let ty = &field.ty;
-                                    let archived_ty = with_ty(field);
+                                    let archived_ty = with_ty(field).unwrap();
                                     partial_ord_where.predicates.push(
                                         parse_quote! { Archived<#archived_ty>: PartialOrd<#ty> },
                                     );
@@ -282,7 +282,7 @@ fn derive_archive_impl(
                             .iter()
                             .filter(|f| !f.attrs.iter().any(|a| a.path.is_ident("omit_bounds")))
                         {
-                            let ty = with_ty(field);
+                            let ty = with_ty(field).unwrap();
                             copy_safe_where
                                 .predicates
                                 .push(parse_quote! { #ty: #rkyv_path::copy::ArchiveCopySafe });
@@ -331,25 +331,25 @@ fn derive_archive_impl(
                         .iter()
                         .filter(|f| !f.attrs.iter().any(|a| a.path.is_ident("omit_bounds")))
                     {
-                        let ty = with_ty(field);
+                        let ty = with_ty(field)?;
                         archive_where
                             .predicates
                             .push(parse_quote! { #ty: #rkyv_path::Archive });
                     }
 
                     let resolver_fields = fields.unnamed.iter().map(|f| {
-                        let ty = with_ty(f);
-                        quote_spanned! { f.span() => #rkyv_path::Resolver<#ty> }
+                        let ty = with_ty(f).unwrap();
+                        quote! { #rkyv_path::Resolver<#ty> }
                     });
 
                     let archived_def = if attributes.archive_as.is_none() {
                         let archived_fields = fields.unnamed.iter().enumerate().map(|(i, f)| {
-                            let ty = with_ty(f);
+                            let ty = with_ty(f).unwrap();
                             let vis = &f.vis;
                             let field_doc =
                                 format!("The archived counterpart of [`{}::{}`]", name, i);
                             let archive_attrs = field_archive_attrs(f);
-                            quote_spanned! { f.span() =>
+                            quote! {
                                 #[doc = #field_doc]
                                 #(#[#archive_attrs])*
                                 #vis #rkyv_path::Archived<#ty>
@@ -369,10 +369,10 @@ fn derive_archive_impl(
 
                     let resolve_fields = fields.unnamed.iter().enumerate().map(|(i, f)| {
                         let index = Index::from(i);
-                        let field = with_cast(f, parse_quote! { (&self.#index) });
-                        quote_spanned! { f.span() =>
+                        let field = with_cast(f, parse_quote! { (&self.#index) }).unwrap();
+                        quote! {
                             let (fp, fo) = out_field!(out.#index);
-                            #field.resolve(pos + fp, resolver.#index, fo);
+                            ::rkyv::Archive::resolve(#field, pos + fp, resolver.#index, fo);
                         }
                     });
 
@@ -385,7 +385,7 @@ fn derive_archive_impl(
                                 for field in fields.unnamed.iter().filter(|f| {
                                     !f.attrs.iter().any(|a| a.path.is_ident("omit_bounds"))
                                 }) {
-                                    let ty = with_ty(field);
+                                    let ty = with_ty(field).unwrap();
                                     partial_eq_where
                                         .predicates
                                         .push(parse_quote! { Archived<#ty>: PartialEq<#ty> });
@@ -417,7 +417,7 @@ fn derive_archive_impl(
                                 for field in fields.unnamed.iter().filter(|f| {
                                     !f.attrs.iter().any(|a| a.path.is_ident("omit_bounds"))
                                 }) {
-                                    let ty = with_ty(field);
+                                    let ty = with_ty(field).unwrap();
                                     partial_ord_where
                                         .predicates
                                         .push(parse_quote! { Archived<#ty>: PartialOrd<#ty> });
@@ -464,7 +464,7 @@ fn derive_archive_impl(
                             .iter()
                             .filter(|f| !f.attrs.iter().any(|a| a.path.is_ident("omit_bounds")))
                         {
-                            let ty = with_ty(field);
+                            let ty = with_ty(field).unwrap();
                             copy_safe_where
                                 .predicates
                                 .push(parse_quote! { #ty: #rkyv_path::copy::ArchiveCopySafe });
@@ -608,7 +608,7 @@ fn derive_archive_impl(
                             .iter()
                             .filter(|f| !f.attrs.iter().any(|a| a.path.is_ident("omit_bounds")))
                         {
-                            let ty = with_ty(field);
+                            let ty = with_ty(field)?;
                             archive_where
                                 .predicates
                                 .push(parse_quote! { #ty: #rkyv_path::Archive });
@@ -620,7 +620,7 @@ fn derive_archive_impl(
                             .iter()
                             .filter(|f| !f.attrs.iter().any(|a| a.path.is_ident("omit_bounds")))
                         {
-                            let ty = with_ty(field);
+                            let ty = with_ty(field)?;
                             archive_where
                                 .predicates
                                 .push(parse_quote! { #ty: #rkyv_path::Archive });
@@ -636,20 +636,20 @@ fn derive_archive_impl(
                     Fields::Named(ref fields) => {
                         let fields = fields.named.iter().map(|f| {
                             let field_name = f.ident.as_ref();
-                            let ty = with_ty(f);
+                            let ty = with_ty(f).unwrap();
                             let field_doc = format!(
                                 "The resolver for [`{}::{}::{}`]",
                                 name,
                                 variant,
                                 field_name.unwrap(),
                             );
-                            quote_spanned! { f.span() =>
+                            quote! {
                                 #[doc = #field_doc]
                                 #field_name: #rkyv_path::Resolver<#ty>
                             }
                         });
                         let variant_doc = format!("The resolver for [`{}::{}`]", name, variant);
-                        quote_spanned! { variant.span() =>
+                        quote! {
                             #[doc = #variant_doc]
                             #[allow(dead_code)]
                             #variant {
@@ -659,16 +659,16 @@ fn derive_archive_impl(
                     }
                     Fields::Unnamed(ref fields) => {
                         let fields = fields.unnamed.iter().enumerate().map(|(i, f)| {
-                            let ty = with_ty(f);
+                            let ty = with_ty(f).unwrap();
                             let field_doc =
                                 format!("The resolver for [`{}::{}::{}`]", name, variant, i);
-                            quote_spanned! { f.span() =>
+                            quote! {
                                 #[doc = #field_doc]
                                 #rkyv_path::Resolver<#ty>
                             }
                         });
                         let variant_doc = format!("The resolver for [`{}::{}`]", name, variant);
-                        quote_spanned! { variant.span() =>
+                        quote! {
                             #[doc = #variant_doc]
                             #[allow(dead_code)]
                             #variant(#(#fields,)*)
@@ -676,7 +676,7 @@ fn derive_archive_impl(
                     }
                     Fields::Unit => {
                         let variant_doc = format!("The resolver for [`{}::{}`]", name, variant);
-                        quote_spanned! { variant.span() =>
+                        quote! {
                             #[doc = #variant_doc]
                             #[allow(dead_code)]
                             #variant
@@ -693,24 +693,24 @@ fn derive_archive_impl(
                         let self_bindings = fields.named.iter().map(|f| {
                             let name = &f.ident;
                             let binding = Ident::new(&format!("self_{}", strip_raw(name.as_ref().unwrap())), name.span());
-                            quote_spanned! { name.span() => #name: #binding }
+                            quote! { #name: #binding }
                         });
                         let resolver_bindings = fields.named.iter().map(|f| {
                             let name = &f.ident;
                             let binding = Ident::new(&format!("resolver_{}", strip_raw(name.as_ref().unwrap())), name.span());
-                            quote_spanned! { binding.span() => #name: #binding }
+                            quote! { #name: #binding }
                         });
                         let resolves = fields.named.iter().map(|f| {
                             let name = &f.ident;
                             let self_binding = Ident::new(&format!("self_{}", strip_raw(name.as_ref().unwrap())), name.span());
                             let resolver_binding = Ident::new(&format!("resolver_{}", strip_raw(name.as_ref().unwrap())), name.span());
-                            let value = with_cast(f, parse_quote! { #self_binding });
+                            let value = with_cast(f, parse_quote! { #self_binding }).unwrap();
                             quote! {
                                 let (fp, fo) = out_field!(out.#name);
-                                #value.resolve(pos + fp, #resolver_binding, fo);
+                                ::rkyv::Archive::resolve(#value, pos + fp, #resolver_binding, fo);
                             }
                         });
-                        quote_spanned! { name.span() =>
+                        quote! {
                             #resolver::#variant { #(#resolver_bindings,)* } => {
                                 match self {
                                     #name::#variant { #(#self_bindings,)* } => {
@@ -728,23 +728,23 @@ fn derive_archive_impl(
                     Fields::Unnamed(ref fields) => {
                         let self_bindings = fields.unnamed.iter().enumerate().map(|(i, f)| {
                             let name = Ident::new(&format!("self_{}", i), f.span());
-                            quote_spanned! { f.span() => #name }
+                            quote! { #name }
                         });
                         let resolver_bindings = fields.unnamed.iter().enumerate().map(|(i, f)| {
                             let name = Ident::new(&format!("resolver_{}", i), f.span());
-                            quote_spanned! { f.span() => #name }
+                            quote! { #name }
                         });
                         let resolves = fields.unnamed.iter().enumerate().map(|(i, f)| {
                             let index = Index::from(i + 1);
                             let self_binding = Ident::new(&format!("self_{}", i), f.span());
                             let resolver_binding = Ident::new(&format!("resolver_{}", i), f.span());
-                            let value = with_cast(f, parse_quote! { #self_binding });
+                            let value = with_cast(f, parse_quote! { #self_binding }).unwrap();
                             quote! {
                                 let (fp, fo) = out_field!(out.#index);
-                                #value.resolve(pos + fp, #resolver_binding, fo);
+                                ::rkyv::Archive::resolve(#value, pos + fp, #resolver_binding, fo);
                             }
                         });
-                        quote_spanned! { name.span() =>
+                        quote! {
                             #resolver::#variant( #(#resolver_bindings,)* ) => {
                                 match self {
                                     #name::#variant(#(#self_bindings,)*) => {
@@ -758,7 +758,7 @@ fn derive_archive_impl(
                             }
                         }
                     }
-                    Fields::Unit => quote_spanned! { name.span() =>
+                    Fields::Unit => quote! {
                         #resolver::#variant => {
                             out.cast::<ArchivedTag>().write(ArchivedTag::#variant);
                         }
@@ -822,7 +822,7 @@ fn derive_archive_impl(
                         Fields::Named(ref fields) => {
                             let fields = fields.named.iter().map(|f| {
                                 let field_name = f.ident.as_ref();
-                                let ty = with_ty(f);
+                                let ty = with_ty(f).unwrap();
                                 let vis = &f.vis;
                                 let field_doc = format!(
                                     "The archived counterpart of [`{}::{}::{}`]",
@@ -831,7 +831,7 @@ fn derive_archive_impl(
                                     field_name.unwrap(),
                                 );
                                 let archive_attrs = field_archive_attrs(f);
-                                quote_spanned! { f.span() =>
+                                quote! {
                                     #[doc = #field_doc]
                                     #(#[#archive_attrs])*
                                     #vis #field_name: #rkyv_path::Archived<#ty>
@@ -839,7 +839,7 @@ fn derive_archive_impl(
                             });
                             let variant_doc =
                                 format!("The archived counterpart of [`{}::{}`]", name, variant);
-                            quote_spanned! { variant.span() =>
+                            quote! {
                                 #[doc = #variant_doc]
                                 #[allow(dead_code)]
                                 #variant {
@@ -849,14 +849,14 @@ fn derive_archive_impl(
                         }
                         Fields::Unnamed(ref fields) => {
                             let fields = fields.unnamed.iter().enumerate().map(|(i, f)| {
-                                let ty = with_ty(f);
+                                let ty = with_ty(f).unwrap();
                                 let vis = &f.vis;
                                 let field_doc = format!(
                                     "The archived counterpart of [`{}::{}::{}`]",
                                     name, variant, i,
                                 );
                                 let archive_attrs = field_archive_attrs(f);
-                                quote_spanned! { f.span() =>
+                                quote! {
                                     #[doc = #field_doc]
                                     #(#[#archive_attrs])*
                                     #vis #rkyv_path::Archived<#ty>
@@ -864,7 +864,7 @@ fn derive_archive_impl(
                             });
                             let variant_doc =
                                 format!("The archived counterpart of [`{}::{}`]", name, variant);
-                            quote_spanned! { variant.span() =>
+                            quote! {
                                 #[doc = #variant_doc]
                                 #[allow(dead_code)]
                                 #variant(#(#fields,)*) #discriminant
@@ -873,7 +873,7 @@ fn derive_archive_impl(
                         Fields::Unit => {
                             let variant_doc =
                                 format!("The archived counterpart of [`{}::{}`]", name, variant);
-                            quote_spanned! { variant.span() =>
+                            quote! {
                                 #[doc = #variant_doc]
                                 #[allow(dead_code)]
                                 #variant #discriminant
@@ -898,7 +898,7 @@ fn derive_archive_impl(
             let archived_variant_tags = data.variants.iter().enumerate().map(|(i, v)| {
                 let variant = &v.ident;
                 let discriminant = int_repr.enum_discriminant(i);
-                quote_spanned! { variant.span() => #variant #discriminant }
+                quote! { #variant #discriminant }
             });
 
             let archived_variant_structs = data.variants.iter().map(|v| {
@@ -908,10 +908,10 @@ fn derive_archive_impl(
                     Fields::Named(ref fields) => {
                         let fields = fields.named.iter().map(|f| {
                             let name = &f.ident;
-                            let ty = with_ty(f);
-                            quote_spanned! { f.span() => #name: Archived<#ty> }
+                            let ty = with_ty(f).unwrap();
+                            quote! { #name: Archived<#ty> }
                         });
-                        quote_spanned! { name.span() =>
+                        quote! {
                             #[repr(C)]
                             struct #archived_variant_name #generics #archive_where {
                                 __tag: ArchivedTag,
@@ -922,10 +922,10 @@ fn derive_archive_impl(
                     }
                     Fields::Unnamed(ref fields) => {
                         let fields = fields.unnamed.iter().map(|f| {
-                            let ty = with_ty(f);
-                            quote_spanned! { f.span() => Archived<#ty> }
+                            let ty = with_ty(f).unwrap();
+                            quote! { Archived<#ty> }
                         });
-                        quote_spanned! { name.span() =>
+                        quote! {
                             #[repr(C)]
                             struct #archived_variant_name #generics (ArchivedTag, #(#fields,)* PhantomData<#name #ty_generics>) #archive_where;
                         }
@@ -946,7 +946,7 @@ fn derive_archive_impl(
                                     for field in fields.named.iter().filter(|f| {
                                         !f.attrs.iter().any(|a| a.path.is_ident("omit_bounds"))
                                     }) {
-                                        let ty = with_ty(field);
+                                        let ty = with_ty(field).unwrap();
                                         partial_eq_where
                                             .predicates
                                             .push(parse_quote! { Archived<#ty>: PartialEq<#ty> });
@@ -956,7 +956,7 @@ fn derive_archive_impl(
                                     for field in fields.unnamed.iter().filter(|f| {
                                         !f.attrs.iter().any(|a| a.path.is_ident("omit_bounds"))
                                     }) {
-                                        let ty = with_ty(field);
+                                        let ty = with_ty(field).unwrap();
                                         partial_eq_where
                                             .predicates
                                             .push(parse_quote! { Archived<#ty>: PartialEq<#ty> });
@@ -1041,7 +1041,7 @@ fn derive_archive_impl(
                                     for field in fields.named.iter().filter(|f| {
                                         !f.attrs.iter().any(|a| a.path.is_ident("omit_bounds"))
                                     }) {
-                                        let ty = with_ty(field);
+                                        let ty = with_ty(field).unwrap();
                                         partial_ord_where
                                             .predicates
                                             .push(parse_quote! { Archived<#ty>: PartialOrd<#ty> });
@@ -1051,7 +1051,7 @@ fn derive_archive_impl(
                                     for field in fields.unnamed.iter().filter(|f| {
                                         !f.attrs.iter().any(|a| a.path.is_ident("omit_bounds"))
                                     }) {
-                                        let ty = with_ty(field);
+                                        let ty = with_ty(field).unwrap();
                                         partial_ord_where
                                             .predicates
                                             .push(parse_quote! { Archived<#ty>: PartialOrd<#ty> });
@@ -1199,7 +1199,7 @@ fn derive_archive_impl(
                                 .iter()
                                 .filter(|f| !f.attrs.iter().any(|a| a.path.is_ident("omit_bounds")))
                             {
-                                let ty = with_ty(field);
+                                let ty = with_ty(field).unwrap();
                                 copy_safe_where
                                     .predicates
                                     .push(parse_quote! { #ty: #rkyv_path::copy::ArchiveCopySafe });
@@ -1211,7 +1211,7 @@ fn derive_archive_impl(
                                 .iter()
                                 .filter(|f| !f.attrs.iter().any(|a| a.path.is_ident("omit_bounds")))
                             {
-                                let ty = with_ty(field);
+                                let ty = with_ty(field).unwrap();
                                 copy_safe_where
                                     .predicates
                                     .push(parse_quote! { #ty: #rkyv_path::copy::ArchiveCopySafe });
